# Table of Contents

- [transformations-explorer](<./transformations-explorer.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Transformations Explorer](<./Transformations-Explorer.md>)
  - [Overview](<./Transformations-Explorer/Overview.md>)
  - [Benefits](<./Transformations-Explorer/Benefits.md>)
  - [Limitations](<./Transformations-Explorer/Limitations.md>)
  - [Accessing the Transformations Explorer](<./Transformations-Explorer/Accessing-the-Transformations-Explorer.md>)
  - [Filtering in the Transformations Explorer](<./Transformations-Explorer/Filtering-in-the-Transformations-Explorer.md>)
  - [Sorting Transformation Items](<./Transformations-Explorer/Sorting-Transformation-Items.md>)
  - [Customizing Table Columns in the Transformations Explorer](<./Transformations-Explorer/Customizing-Table-Columns-in-the-Transformations-Explorer.md>)
  - [Cell Behavior and Visual Indicators](<./Transformations-Explorer/Cell-Behavior-and-Visual-Indicators.md>)
  - [Editing in the Transformations Explorer](<./Transformations-Explorer/Editing-in-the-Transformations-Explorer.md>)
  - [Managing Impacts in the Transformations Explorer](<./Transformations-Explorer/Managing-Impacts-in-the-Transformations-Explorer.md>)
  - [Executing Transformations in the Transformations Explorer](<./Transformations-Explorer/Executing-Transformations-in-the-Transformations-Explorer.md>)
  - [Exporting Transformation Items to Excel](<./Transformations-Explorer/Exporting-Transformation-Items-to-Excel.md>)
  - [Save How You View Your Data in Transformations Explorer](<./Transformations-Explorer/Save-How-You-View-Your-Data-in-Transformations-Explorer.md>)
  - [Was this page helpful?](<./Transformations-Explorer/Was-this-page-helpful.md>)
